@@ -1,14 +1,11 @@
 #![allow(non_camel_case_types)]
 
-//! *See the [ARB documentation](https://arblib.org/).
+//! *See the [Arb documentation](https://arblib.org/).
 
 use flint_sys::deps::*;
-use flint_sys::flint::*;
-use flint_sys::fmpz::fmpz;
-use flint_sys::fmpq::fmpq;
-use crate::fmpr::fmpr_struct;
-use libc::{c_char, c_int, FILE};
-
+use crate::mag::mag_struct;
+use crate::acb::{acb_struct, acb_ptr, acb_srcptr};
+use crate::acb_poly::acb_poly_struct;
 
 extern "C" {
     pub fn acb_hypgeom_rising_ui_rs(
@@ -18,8 +15,6 @@ extern "C" {
         m: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_bound_factor(
         C: *mut mag_struct,
         a: acb_srcptr,
@@ -29,8 +24,6 @@ extern "C" {
         z: *mut acb_struct,
         n: mp_limb_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_choose_n(
         a: acb_srcptr,
         p: mp_limb_signed_t,
@@ -39,8 +32,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     ) -> mp_limb_signed_t;
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_sum_forward(
         s: *mut acb_struct,
         t: *mut acb_struct,
@@ -52,8 +43,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_sum_rs(
         s: *mut acb_struct,
         t: *mut acb_struct,
@@ -65,8 +54,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_sum_bs(
         s: *mut acb_struct,
         t: *mut acb_struct,
@@ -78,8 +65,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_sum_fme(
         s: *mut acb_struct,
         t: *mut acb_struct,
@@ -91,8 +76,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_sum(
         s: *mut acb_struct,
         t: *mut acb_struct,
@@ -104,8 +87,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_sum_bs_invz(
         s: *mut acb_struct,
         t: *mut acb_struct,
@@ -117,8 +98,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_sum_invz(
         s: *mut acb_struct,
         t: *mut acb_struct,
@@ -131,8 +110,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_direct(
         res: *mut acb_struct,
         a: acb_srcptr,
@@ -143,8 +120,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_series_choose_n(
         a: *const acb_poly_struct,
         p: mp_limb_signed_t,
@@ -154,8 +129,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     ) -> mp_limb_signed_t;
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_series_sum_forward(
         s: *mut acb_poly_struct,
         t: *mut acb_poly_struct,
@@ -169,8 +142,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_series_sum_bs(
         s: *mut acb_poly_struct,
         t: *mut acb_poly_struct,
@@ -184,8 +155,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_series_sum_rs(
         s: *mut acb_poly_struct,
         t: *mut acb_poly_struct,
@@ -199,8 +168,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_series_sum(
         s: *mut acb_poly_struct,
         t: *mut acb_poly_struct,
@@ -214,8 +181,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq_series_direct(
         res: *mut acb_poly_struct,
         a: *const acb_poly_struct,
@@ -228,8 +193,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_pfq(
         res: *mut acb_struct,
         a: acb_srcptr,
@@ -240,8 +203,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_u_asymp(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -250,8 +211,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_u_1f1_series(
         res: *mut acb_poly_struct,
         a: *mut acb_poly_struct,
@@ -260,8 +219,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_u_1f1(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -269,8 +226,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_u(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -278,14 +233,10 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_u_use_asymp(
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     ) -> ::std::os::raw::c_int;
-}
-extern "C" {
     pub fn acb_hypgeom_m_asymp(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -294,8 +245,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_m_1f1(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -304,8 +253,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_m(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -314,8 +261,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_1f1(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -324,32 +269,24 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_j_0f1(
         res: *mut acb_struct,
         nu: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_j_asymp(
         res: *mut acb_struct,
         nu: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_j(
         res: *mut acb_struct,
         nu: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_i_0f1(
         res: *mut acb_struct,
         nu: *mut acb_struct,
@@ -357,8 +294,6 @@ extern "C" {
         scaled: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_i_asymp(
         res: *mut acb_struct,
         nu: *mut acb_struct,
@@ -366,24 +301,18 @@ extern "C" {
         scaled: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_i(
         res: *mut acb_struct,
         nu: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_i_scaled(
         res: *mut acb_struct,
         nu: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_k_0f1(
         res: *mut acb_struct,
         nu: *mut acb_struct,
@@ -391,8 +320,6 @@ extern "C" {
         scaled: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_k_0f1_series(
         res: *mut acb_poly_struct,
         n: *mut acb_poly_struct,
@@ -401,8 +328,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_k_asymp(
         res: *mut acb_struct,
         nu: *mut acb_struct,
@@ -410,32 +335,24 @@ extern "C" {
         scaled: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_k(
         res: *mut acb_struct,
         nu: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_k_scaled(
         res: *mut acb_struct,
         nu: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_y(
         res: *mut acb_struct,
         nu: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_bessel_jy(
         res1: *mut acb_struct,
         res2: *mut acb_struct,
@@ -443,8 +360,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_0f1_asymp(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -452,8 +367,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_0f1_direct(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -461,8 +374,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_0f1(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -470,8 +381,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_airy_bound(
         ai: *mut mag_struct,
         aip: *mut mag_struct,
@@ -479,8 +388,6 @@ extern "C" {
         bip: *mut mag_struct,
         z: *mut acb_struct,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_airy_asymp(
         ai: *mut acb_struct,
         aip: *mut acb_struct,
@@ -490,8 +397,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_airy_direct(
         ai: *mut acb_struct,
         aip: *mut acb_struct,
@@ -501,8 +406,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_airy(
         ai: *mut acb_struct,
         aip: *mut acb_struct,
@@ -511,8 +414,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_airy_jet(
         ai: acb_ptr,
         bi: acb_ptr,
@@ -520,8 +421,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_hypgeom_airy_series(
         ai: acb_ptr,
         ai_prime: acb_ptr,
@@ -532,8 +431,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_airy_series(
         ai: *mut acb_poly_struct,
         ai_prime: *mut acb_poly_struct,
@@ -543,8 +440,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_coulomb(
         F: *mut acb_struct,
         G: *mut acb_struct,
@@ -555,8 +450,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_coulomb_jet(
         F: acb_ptr,
         G: acb_ptr,
@@ -568,8 +461,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_hypgeom_coulomb_series(
         F: acb_ptr,
         G: acb_ptr,
@@ -582,8 +473,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_coulomb_series(
         F: *mut acb_poly_struct,
         G: *mut acb_poly_struct,
@@ -595,8 +484,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gamma_upper_asymp(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -604,8 +491,6 @@ extern "C" {
         modified: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gamma_upper_1f1a(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -613,8 +498,6 @@ extern "C" {
         modified: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gamma_upper_1f1b(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -622,8 +505,6 @@ extern "C" {
         modified: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gamma_upper_singular(
         res: *mut acb_struct,
         s: mp_limb_signed_t,
@@ -631,8 +512,6 @@ extern "C" {
         modified: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gamma_upper(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -640,8 +519,6 @@ extern "C" {
         modified: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_hypgeom_gamma_upper_series(
         g: acb_ptr,
         s: *mut acb_struct,
@@ -651,8 +528,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gamma_upper_series(
         g: *mut acb_poly_struct,
         s: *mut acb_struct,
@@ -661,8 +536,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gamma_lower(
         res: *mut acb_struct,
         s: *mut acb_struct,
@@ -670,8 +543,6 @@ extern "C" {
         modified: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_hypgeom_gamma_lower_series(
         g: acb_ptr,
         s: *mut acb_struct,
@@ -681,8 +552,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gamma_lower_series(
         g: *mut acb_poly_struct,
         s: *mut acb_struct,
@@ -691,8 +560,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_beta_lower(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -701,8 +568,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_hypgeom_beta_lower_series(
         res: acb_ptr,
         a: *mut acb_struct,
@@ -713,8 +578,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_beta_lower_series(
         res: *mut acb_poly_struct,
         a: *mut acb_struct,
@@ -724,29 +587,19 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_expint(
         res: *mut acb_struct,
         s: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_erf_propagated_error(
         re: *mut mag_struct,
         im: *mut mag_struct,
         z: *mut acb_struct,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_erf_1f1a(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_erf_1f1b(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_erf_asymp(
         res: *mut acb_struct,
         z: *mut acb_struct,
@@ -754,11 +607,7 @@ extern "C" {
         prec: mp_limb_signed_t,
         prec2: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_erf(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _acb_hypgeom_erf_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -766,19 +615,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_erf_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_erfc(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _acb_hypgeom_erfc_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -786,19 +629,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_erfc_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_erfi(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _acb_hypgeom_erfi_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -806,16 +643,12 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_erfi_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_fresnel(
         res1: *mut acb_struct,
         res2: *mut acb_struct,
@@ -823,8 +656,6 @@ extern "C" {
         normalized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_hypgeom_fresnel_series(
         s: acb_ptr,
         c: acb_ptr,
@@ -834,8 +665,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_fresnel_series(
         s: *mut acb_poly_struct,
         c: *mut acb_poly_struct,
@@ -844,17 +673,9 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_ei_asymp(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_ei_2f2(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_ei(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _acb_hypgeom_ei_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -862,25 +683,15 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_ei_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_si_asymp(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_si_1f2(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_si(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _acb_hypgeom_si_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -888,25 +699,15 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_si_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_ci_asymp(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_ci_2f3(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_ci(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _acb_hypgeom_ci_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -914,19 +715,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_ci_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_shi(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _acb_hypgeom_shi_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -934,25 +729,15 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_shi_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_chi_asymp(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_chi_2f3(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_chi(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _acb_hypgeom_chi_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -960,24 +745,18 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_chi_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_li(
         res: *mut acb_struct,
         z: *mut acb_struct,
         offset: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _acb_hypgeom_li_series(
         g: acb_ptr,
         h: acb_srcptr,
@@ -986,8 +765,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_li_series(
         g: *mut acb_poly_struct,
         h: *mut acb_poly_struct,
@@ -995,8 +772,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_2f1_continuation(
         res0: *mut acb_struct,
         res1: *mut acb_struct,
@@ -1009,8 +784,6 @@ extern "C" {
         f1: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_2f1_series_direct(
         res: *mut acb_poly_struct,
         a: *mut acb_poly_struct,
@@ -1021,8 +794,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_2f1_direct(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -1032,8 +803,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_2f1_transform(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -1044,8 +813,6 @@ extern "C" {
         which: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_2f1_transform_limit(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -1056,8 +823,6 @@ extern "C" {
         which: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_2f1_corner(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -1067,11 +832,7 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_2f1_choose(z: *mut acb_struct) -> ::std::os::raw::c_int;
-}
-extern "C" {
     pub fn acb_hypgeom_2f1(
         res: *mut acb_struct,
         a: *mut acb_struct,
@@ -1081,8 +842,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_legendre_p_uiui_rec(
         res: *mut acb_struct,
         n: mp_limb_t,
@@ -1090,8 +849,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_legendre_p(
         res: *mut acb_struct,
         n: *mut acb_struct,
@@ -1100,8 +857,6 @@ extern "C" {
         type_: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_legendre_q(
         res: *mut acb_struct,
         n: *mut acb_struct,
@@ -1110,8 +865,6 @@ extern "C" {
         type_: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_jacobi_p(
         res: *mut acb_struct,
         n: *mut acb_struct,
@@ -1120,8 +873,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_gegenbauer_c(
         res: *mut acb_struct,
         n: *mut acb_struct,
@@ -1129,8 +880,6 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_laguerre_l(
         res: *mut acb_struct,
         n: *mut acb_struct,
@@ -1138,32 +887,24 @@ extern "C" {
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_hermite_h(
         res: *mut acb_struct,
         n: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_chebyshev_t(
         res: *mut acb_struct,
         n: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_chebyshev_u(
         res: *mut acb_struct,
         n: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_spherical_y(
         res: *mut acb_struct,
         n: mp_limb_signed_t,
@@ -1172,48 +913,34 @@ extern "C" {
         phi: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_dilog_bernoulli(
         res: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_dilog_continuation(
         res: *mut acb_struct,
         a: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_dilog_bitburst(
         res: *mut acb_struct,
         z0: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_dilog_transform(
         res: *mut acb_struct,
         z: *mut acb_struct,
         algorithm: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_dilog_zero_taylor(
         res: *mut acb_struct,
         z: *mut acb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn acb_hypgeom_dilog_zero(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn acb_hypgeom_dilog(res: *mut acb_struct, z: *mut acb_struct, prec: mp_limb_signed_t);
 }
