@@ -1,33 +1,24 @@
 #![allow(non_camel_case_types)]
 
-//! *See the [ARB documentation](https://arblib.org/).
+//! *See the [Arb documentation](https://arblib.org/).
 
 use flint_sys::deps::*;
-use flint_sys::flint::*;
 use flint_sys::fmpz::fmpz;
-use flint_sys::fmpq::fmpq;
-use crate::fmpr::fmpr_struct;
-use libc::{c_char, c_int, FILE};
+use crate::mag::mag_struct;
+use crate::arb::{arb_struct, arb_ptr, arb_srcptr};
+use crate::arb_poly::arb_poly_struct;
 
 
 extern "C" {
     pub fn _arb_hypgeom_rising_coeffs_1(c: *mut mp_limb_t, k: mp_limb_t, l: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_rising_coeffs_2(c: *mut mp_limb_t, k: mp_limb_t, l: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_rising_coeffs_fmpz(c: *mut fmpz, k: mp_limb_t, l: mp_limb_signed_t);
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui_forward(
         res: *mut arb_struct,
         x: *mut arb_struct,
         n: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui_rs(
         res: *mut arb_struct,
         x: *mut arb_struct,
@@ -35,40 +26,30 @@ extern "C" {
         m: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui_bs(
         res: *mut arb_struct,
         x: *mut arb_struct,
         n: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui_rec(
         res: *mut arb_struct,
         x: *mut arb_struct,
         n: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui(
         y: *mut arb_struct,
         x: *mut arb_struct,
         n: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising(
         y: *mut arb_struct,
         x: *mut arb_struct,
         n: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui_jet_powsum(
         res: arb_ptr,
         x: *mut arb_struct,
@@ -76,8 +57,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui_jet_rs(
         res: arb_ptr,
         x: *mut arb_struct,
@@ -86,8 +65,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui_jet_bs(
         res: arb_ptr,
         x: *mut arb_struct,
@@ -95,8 +72,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_rising_ui_jet(
         res: arb_ptr,
         x: *mut arb_struct,
@@ -104,8 +79,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_pfq(
         res: *mut arb_struct,
         a: arb_srcptr,
@@ -116,8 +89,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_0f1(
         res: *mut arb_struct,
         a: *mut arb_struct,
@@ -125,8 +96,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_m(
         res: *mut arb_struct,
         a: *mut arb_struct,
@@ -135,8 +104,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_1f1(
         res: *mut arb_struct,
         a: *mut arb_struct,
@@ -145,8 +112,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_u(
         res: *mut arb_struct,
         a: *mut arb_struct,
@@ -154,8 +119,6 @@ extern "C" {
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_2f1(
         res: *mut arb_struct,
         a: *mut arb_struct,
@@ -165,11 +128,7 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_erf(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_erf_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -177,19 +136,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_erf_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_erfc(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_erfc_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -197,19 +150,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_erfc_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_erfi(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_erfi_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -217,16 +164,12 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_erfi_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_fresnel(
         res1: *mut arb_struct,
         res2: *mut arb_struct,
@@ -234,8 +177,6 @@ extern "C" {
         normalized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _arb_hypgeom_fresnel_series(
         s: arb_ptr,
         c: arb_ptr,
@@ -245,8 +186,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_fresnel_series(
         s: *mut arb_poly_struct,
         c: *mut arb_poly_struct,
@@ -255,11 +194,7 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_ei(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_ei_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -267,19 +202,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_ei_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_si(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_si_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -287,19 +216,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_si_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_ci(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_ci_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -307,19 +230,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_ci_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_shi(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_shi_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -327,19 +244,13 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_shi_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_chi(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn _arb_hypgeom_chi_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -347,24 +258,18 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_chi_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_li(
         res: *mut arb_struct,
         z: *mut arb_struct,
         offset: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _arb_hypgeom_li_series(
         g: arb_ptr,
         h: arb_srcptr,
@@ -373,8 +278,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_li_series(
         g: *mut arb_poly_struct,
         h: *mut arb_poly_struct,
@@ -382,24 +285,18 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_bessel_j(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_bessel_y(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_bessel_jy(
         res1: *mut arb_struct,
         res2: *mut arb_struct,
@@ -407,40 +304,30 @@ extern "C" {
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_bessel_i(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_bessel_k(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_bessel_i_scaled(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_bessel_k_scaled(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_airy(
         ai: *mut arb_struct,
         aip: *mut arb_struct,
@@ -449,8 +336,6 @@ extern "C" {
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_airy_jet(
         ai: arb_ptr,
         bi: arb_ptr,
@@ -458,8 +343,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_airy_series(
         ai: *mut arb_poly_struct,
         ai_prime: *mut arb_poly_struct,
@@ -469,8 +352,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _arb_hypgeom_airy_series(
         ai: arb_ptr,
         ai_prime: arb_ptr,
@@ -481,8 +362,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_airy_zero(
         ai: *mut arb_struct,
         aip: *mut arb_struct,
@@ -491,8 +370,6 @@ extern "C" {
         n: *mut fmpz,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_coulomb(
         F: *mut arb_struct,
         G: *mut arb_struct,
@@ -501,8 +378,6 @@ extern "C" {
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_coulomb_jet(
         F: arb_ptr,
         G: arb_ptr,
@@ -512,8 +387,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _arb_hypgeom_coulomb_series(
         F: arb_ptr,
         G: arb_ptr,
@@ -524,8 +397,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_coulomb_series(
         F: *mut arb_poly_struct,
         G: *mut arb_poly_struct,
@@ -535,16 +406,12 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_expint(
         res: *mut arb_struct,
         s: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_gamma_lower(
         res: *mut arb_struct,
         s: *mut arb_struct,
@@ -552,8 +419,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _arb_hypgeom_gamma_lower_series(
         g: arb_ptr,
         s: *mut arb_struct,
@@ -563,8 +428,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_gamma_lower_series(
         g: *mut arb_poly_struct,
         s: *mut arb_struct,
@@ -573,8 +436,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_gamma_upper(
         res: *mut arb_struct,
         s: *mut arb_struct,
@@ -582,8 +443,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _arb_hypgeom_gamma_upper_series(
         g: arb_ptr,
         s: *mut arb_struct,
@@ -593,8 +452,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_gamma_upper_series(
         g: *mut arb_poly_struct,
         s: *mut arb_struct,
@@ -603,8 +460,6 @@ extern "C" {
         n: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_beta_lower(
         res: *mut arb_struct,
         a: *mut arb_struct,
@@ -613,8 +468,6 @@ extern "C" {
         regularized: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_beta_lower_series(
         res: *mut arb_poly_struct,
         a: *mut arb_struct,
@@ -624,8 +477,6 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn _arb_hypgeom_beta_lower_series(
         res: arb_ptr,
         a: *mut arb_struct,
@@ -636,24 +487,18 @@ extern "C" {
         len: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_chebyshev_t(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_chebyshev_u(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_jacobi_p(
         res: *mut arb_struct,
         n: *mut arb_struct,
@@ -662,8 +507,6 @@ extern "C" {
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_gegenbauer_c(
         res: *mut arb_struct,
         n: *mut arb_struct,
@@ -671,8 +514,6 @@ extern "C" {
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_laguerre_l(
         res: *mut arb_struct,
         n: *mut arb_struct,
@@ -680,16 +521,12 @@ extern "C" {
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_hermite_h(
         res: *mut arb_struct,
         nu: *mut arb_struct,
         z: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_p(
         res: *mut arb_struct,
         n: *mut arb_struct,
@@ -698,8 +535,6 @@ extern "C" {
         type_: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_q(
         res: *mut arb_struct,
         n: *mut arb_struct,
@@ -708,8 +543,6 @@ extern "C" {
         type_: ::std::os::raw::c_int,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_p_ui_deriv_bound(
         dp: *mut mag_struct,
         dp2: *mut mag_struct,
@@ -717,8 +550,6 @@ extern "C" {
         x: *mut arb_struct,
         x2sub1: *mut arb_struct,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_p_ui_rec(
         res: *mut arb_struct,
         res_prime: *mut arb_struct,
@@ -726,8 +557,6 @@ extern "C" {
         x: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_p_ui_asymp(
         res: *mut arb_struct,
         res2: *mut arb_struct,
@@ -736,8 +565,6 @@ extern "C" {
         K: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_p_ui_one(
         res: *mut arb_struct,
         res2: *mut arb_struct,
@@ -746,8 +573,6 @@ extern "C" {
         K: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_p_ui_zero(
         res: *mut arb_struct,
         res2: *mut arb_struct,
@@ -756,8 +581,6 @@ extern "C" {
         K: mp_limb_signed_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_p_ui(
         res: *mut arb_struct,
         res_prime: *mut arb_struct,
@@ -765,8 +588,6 @@ extern "C" {
         x: *mut arb_struct,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_legendre_p_ui_root(
         res: *mut arb_struct,
         weight: *mut arb_struct,
@@ -774,10 +595,6 @@ extern "C" {
         k: mp_limb_t,
         prec: mp_limb_signed_t,
     );
-}
-extern "C" {
     pub fn arb_hypgeom_central_bin_ui(res: *mut arb_struct, n: mp_limb_t, prec: mp_limb_signed_t);
-}
-extern "C" {
     pub fn arb_hypgeom_dilog(res: *mut arb_struct, z: *mut arb_struct, prec: mp_limb_signed_t);
-}
+    }
